//!OpenSCAD

Width = 25.4;
Length = 101.6;
Thickness = 5.5;
FoldThickness = 1.8;
KerfSpacing = 5;
Number_of_Kerfs = 10;
Generate_G_Code = true;
Keft_Test = "Spacing";

/* [CAM settings] */
Endmill_Number = 21;
ballnose = 1.5875;
Vangle = 3.6;
EndmillDiameter = 6.35;
speed = 18000;
feedrate = 600;
plungerate = 150;
safeheight = 8;

endmillradius = EndmillDiameter / 2;
groovewidth = sin((Vangle / 2)) * ((Thickness - FoldThickness) - ballnose / 2) + ballnose;

//Width = 1;
//Length = 4;
//Thickness = 0.216;
//FoldThickness = 0.072;
//KerfSpacing = 0.2;
//Number_of_Kerfs = 10;
//ballnose = 0.0625;
//Vangle = 3.6;
//EndmillDiameter = 0.25;

echo(str("G90"));
echo(str("G21"));
echo(str("M05"));
echo(str("M6T",Endmill_Number));
echo(str("M03S",speed));

module groove(gx, gy, gz, gw) {

echo(str("G0 X",gx," Y",gy," Z",safeheight));
echo(str("G1 Z",gz," F",plungerate));
echo(str("G1 X",gx + gw," Y",gy," F",feedrate));
echo(str("G0 Z",safeheight));

  translate([gx, gy, gz]){
    hull(){
      ballendmill();
      translate([gw, 0, 0]){
        ballendmill();
      }
    }
  }
}

module ballendmill() {
  translate([0, 0, (ballnose / 2)]){
    cylinder(r1=(ballnose / 2), r2=endmillradius, h=(endmillradius / tan((Vangle / 2))), center=false);
    sphere(r=(ballnose / 2));
  }
}

difference() {
  for (i = [0 : abs(1) : Number_of_Kerfs - 1]) {
    translate([(i * (Width + EndmillDiameter * 1.1)), 0, 0]){
      cube([Width, Length, Thickness], center=false);
    }
  }

  if (Keft_Test == "Spacing") {
    for (j = [0 : abs(1) : Number_of_Kerfs - 1]) {
      for (k = [0 : abs(1) : Number_of_Kerfs - 1]) {
        groove(j * (Width + EndmillDiameter * 1.1), ((Length - groovewidth * Number_of_Kerfs) / 2 - (Number_of_Kerfs * (KerfSpacing * (j / Number_of_Kerfs))) / 2) + (k * (KerfSpacing * (j / Number_of_Kerfs)) + k * groovewidth), FoldThickness, Width);
      }

    }

  } else {
    for (j = [0 : abs(1) : Number_of_Kerfs - 1]) {
      for (k = [1 : abs(1) : j + 1]) {
        groove(j * (Width + EndmillDiameter * 1.1), (Length / 2 + (j * (KerfSpacing + ballnose)) / 2) - (k - 1) * (KerfSpacing + ballnose), FoldThickness, Width);
      }

    }

  }

}

echo(str("M02"));
